using System;
using System.Collections.Generic;
using System.Windows.Forms;
using KellermanSoftware.UserAgentParser;

namespace Device_Detector_Demo
{


    public partial class MainForm : Form
    {
        private DetectionLogic _detection = new DetectionLogic();
        private string _userAgentString;
        private bool _updating = false;

        public MainForm()
        {
            InitializeComponent();            
        }

        private void detectButton_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrEmpty(userAgentTextBox.Text))
            {
                return;
            }
            DeviceInformation deviceInformation = _detection.DetectDevice(userAgentTextBox.Text);
            easyBrowserLabel.Text = "Easy Browser:  " + deviceInformation.EasyBrowser;
            easyPlatformLabel.Text = "Easy Platform:  " + deviceInformation.EasyPlatform;
            browserTypeLabel.Text = "Browser Type:  " + deviceInformation.BrowserType;
            isTouchLabel.Text = "Is Touch:  " + (deviceInformation.IsTouch ? "Yes" : "No");
            browserNameLabel.Text = "Browser Name: " + deviceInformation.BrowserName;
            browserVersionLabel.Text = "Browser Version: " + deviceInformation.BrowserVersion;
            layoutEngineLabel.Text = "Layout Engine: " + deviceInformation.LayoutEngine;
            layoutEngineVersionLabel.Text = "Layout Engine Version: " + deviceInformation.LayoutEngineVersion;
            cultureLabel.Text = "Culture: " + deviceInformation.Culture;
            securityLevelLabel.Text = "Security Level: " + deviceInformation.SecurityLevel;
            brandLabel.Text = "Brand: " + deviceInformation.BrandName;
            identifierLabel.Text = "Identifier: " + deviceInformation.Identifier;
            modelNumberLabel.Text = "Model Number: " + deviceInformation.ModelNumber;
            modelNameLabel.Text = "Model Name: " + deviceInformation.ModelName;
            operatingSystemLabel.Text = "Operating System: " + deviceInformation.OperatingSystem;
            operatingSystemVersionLabel.Text = "Operating System Version: " + deviceInformation.OperatingSystemVersion;
            processorTypeLabel.Text = "Processor Type: " + deviceInformation.ProcessorType;

            grdBrowser.DataSource = deviceInformation.BrowserProperties;
            grdDeviceProperties.DataSource = deviceInformation.ModelProperties;
            pnlBottom.Visible = true;

        }


        private void pasteButton_Click(object sender, EventArgs e)
        {
            userAgentTextBox.Text = Clipboard.GetText();
        }

        private void devicesListBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (devicesListBox.SelectedIndex == -1)
                return;

            switch(devicesListBox.SelectedItem.ToString())
            {
                case "Android Phone": 
                    _userAgentString =
                        "Mozilla/5.0 (Linux; Android 4.1.2; GT-N5110 Build/JZO54K) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.114 Safari/537.36";
                    break;
                case "iPhone": 
                    _userAgentString =
                        "Mozilla/5.0 (iPhone; CPU iPhone OS 11_0 like Mac OS X) AppleWebKit/604.1.38 (KHTML, like Gecko) Version/11.0 Mobile/15A372 Safari/604.1";
                    break;
                case "Windows Phone": 
                    _userAgentString = 
                        "Mozilla/5.0 (compatible; MSIE 10.0; Windows Phone 8.0; Trident/6.0; IEMobile/10.0; ARM; Touch; HTC; Windows Phone 8X by HTC)";
                    break;
                case "Blackberry": 
                    _userAgentString = 
                        "Mozilla/5.0 (BlackBerry; U; BlackBerry 9900; en) AppleWebKit/534.11+ (KHTML, like Gecko) Version/7.1.0.346 Mobile Safari/534.11+"; 
                    break;
                case "iPad": 
                    _userAgentString = 
                        "Mozilla/5.0 (iPad; CPU OS 6_0 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/6.0 Mobile/10A5355d Safari/8536.25";
                    break;
                case "Samsung Galaxy Tab": 
                    _userAgentString =
                        "Mozilla/5.0 (Linux; Android 4.4.2; SM-T310 Build/KOT49H) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.141 Safari/537.36";
                    break;
                case "Kindle Fire": 
                    _userAgentString = 
                        "Mozilla/5.0 (Linux; U; Android 2.3.4; en-us; Kindle Fire Build/GINGERBREAD) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1";
                    break;
                case "Playstation 4":
                    _userAgentString = "Mozilla/5.0 (PlayStation 4 1.000) AppleWebKit/536.26 (KHTML, like Gecko)";
                    break;
                case "WiiU":
                    _userAgentString = "Mozilla/5.0 (Nintendo WiiU) AppleWebKit/536.28 (KHTML, like Gecko) NX/3.0.3.12.14 NintendoBrowser/3.1.1.9577.EU";
                    break;
                case "XBox One":
                    _userAgentString = "Mozilla/5.0 (Windows NT 10.0; Win64; x64; Xbox; Xbox One) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/46.0.2486.0 Safari/537.36 Edge/13.10586";
                    break;
                case "Chrome Desktop":
                    _userAgentString =
                        "Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/63.0.3239.84 Safari/537.36";
                    break;
                case "IE Desktop":
                    _userAgentString = "Mozilla/5.0 (Windows NT 6.1; WOW64; Trident/7.0; rv:11.0) like Gecko";
                    break;
                case "Edge Desktop":
                    _userAgentString = "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/51.0.2704.79 Safari/537.36 Edge/14.14393";
                    break;
                case "Firefox Desktop":
                    _userAgentString = "Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:57.0) Gecko/20100101 Firefox/57.0";
                    break;
                case "Opera Desktop":
                    _userAgentString = "Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/56.0.2924.87 Safari/537.36 OPR/43.0.2442.991";
                    break;
                default:
                    _userAgentString = "";
                    break;
            }

            _updating = true;
            userAgentTextBox.Text = _userAgentString;
            _updating = false;
        }

        private void userAgentTextBox_TextChanged(object sender, EventArgs e)
        {
            if (!_updating)
            {
                devicesListBox.SelectedIndex = -1;
            }
        }

        private void userAgentTextBox_KeyDown(object sender, KeyEventArgs e)
        {
            //if (!_updating)
            //{
            //    devicesListBox.SelectedIndex = -1;
            //}
        }        
    }
}
